/**
 * @file libpackman/batch.h Package batch structure and support API
 *
 * $Id: batch.h,v 1.4 2002/03/18 09:51:04 chipx86 Exp $
 *
 * @Copyright (C) 1999-2002 The GNUpdate Project.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef _LIBPACKMAN_BATCH_H_
#define _LIBPACKMAN_BATCH_H_

#ifdef __cplusplus
extern "C" {
#endif

typedef struct _PmBatch PmBatch; /**< PmBatch */

#include <libpackman/package.h>

/**
 * @struct _PmBatch batch.h libpackman/batch.h
 *
 * A list of packages.
 *
 * Operations, such as installing, can be performed on this batch
 * of packages. Dependencies will be worked out among them, and the
 * operation will not be performed on any of them unless it can work
 * for all of them.
 */
struct _PmBatch
{
	PmPackage *firstPackage;   /**< First package in the batch. */
	PmPackage *lastPackage;    /**< Last package in the batch.  */

	unsigned int count;        /**< Number of packages.         */

	unsigned char _checkingDeps; /**< Reserved. Don't touch.    */
	unsigned char _curStep;      /**< Reserved. Don't touch.    */
	unsigned char _totalSteps;   /**< Reserved. Don't touch.    */
};

/**************************************************************************/
/** @name PmBatch (De)allocation Functions                                */
/**************************************************************************/
/*@{*/

/**
 * Creates a new PmBatch structure.
 *
 * @return A new, empty PmBatch structure.
 */
PmBatch *pmNewBatch(void);

/**
 * Destroys a PmBatch structure.
 *
 * Destroying the batch is the only way to free up the memory used by
 * all the packages stored inside.
 *
 * @param batch The batch to destroy.
 */
void pmDestroyBatch(PmBatch *batch);

/*@}*/


/**************************************************************************/
/** @name Batch Modification Functions                                    */
/**************************************************************************/
/*@{*/

/**
 * Adds a package to a batch.
 *
 * Destroying the package will result in segfaults. To free up the memory,
 * call pmDestroyBatch().
 *
 * @param batch   The batch to add the package to.
 * @param package The package to add.
 */
void pmBatchAddPackage(PmBatch *batch, PmPackage *package);

/*@}*/

#ifdef __cplusplus
}
#endif

#endif /* _LIBPACKMAN_BATCH_H_ */

