/**
 * @file libpackman/db.h Database structures
 * 
 * $Id: db.h,v 1.17 2002/03/05 22:37:28 chipx86 Exp $
 *
 * @Copyright (C) 1999-2002 The GNUpdate Project.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef _LIBPACKMAN_DB_H_
#define _LIBPACKMAN_DB_H_

typedef struct _PmDatabase PmDatabase;  /**< PmDatabase. */
typedef struct _PmMatches PmMatches;    /**< PmMatches.  */

#include <libpackman/module.h>
#include <libpackman/package.h>
#include <libpackman/types.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @struct _PmDatabase db.h libpackman/db.h
 *
 * A package database.
 */
struct _PmDatabase
{
	PmModule *module;         /**< The associated module.    */
	PmAccessMode accessMode;  /**< The database access mode. */
	void *db;                 /**< Module-specific data.     */
};

/**
 * @struct _PmMatches db.h libpackman/db.h
 *
 * Search matches.
 */
struct _PmMatches
{
	PmDatabase *db;        /**< The associated package database. */

	int index;             /**< The index of the match.          */
	int flags;             /**< Flags.                           */

	void *matches;         /**< Module-specific matches data.    */
};

/**
 * Sets the database's access mode.
 *
 * @param db   The database.
 * @param mode The access mode.
 *
 * @see pmGetDbAccessMode()
 */
void pmSetDbAccessMode(PmDatabase *db, PmAccessMode mode);

/**
 * Returns the database's access mode.
 *
 * @param db The database.
 *
 * @return The access mode, or PM_MODE_ERROR if @a db is NULL.
 * 
 * @see pmSetDbAccessMode()
 */
PmAccessMode pmGetDbAccessMode(PmDatabase *db);

#ifdef __cplusplus
};
#endif

#endif /* _LIBPACKMAN_DB_H_ */

