/**
 * @file libpackman/depcheck.h Dependency checking functions
 *
 * $Id: depcheck.h,v 1.3 2002/03/05 22:37:29 chipx86 Exp $
 *
 * @Copyright (C) 1999-2002 The GNUpdate Project.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef _LIBPACKMAN_DEPCHECK_H_
#define _LIBPACKMAN_DEPCHECK_H_

#include <libpackman/types.h>
#include <libpackman/batch.h>
#include <libpackman/package.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Determines if the necessary dependencies are installed for a package.
 *
 * If a file conflicts, it will show up in the list.
 *
 * @param db         The opened database.
 * @param package    The package to check.
 * @param errorList  A linked list of missing or conflicting dependencies.
 * @param errorCount The number of items in @a errorList.
 *
 * @return PM_SUCCESS on success. PM_DEP_ERROR if there are missing or
 *         conflicting dependencies. Other error types if there are problems
 *         with the database or package.
 *
 * @see pmCheckBatchDeps(3)
 */
PmStatus pmCheckDeps(PmDatabase *db, PmPackage *package,
					 PmDependency **errorList, unsigned int *errorCount);

/**
 * Determines if the necessary dependencies are installed for all packages
 * in a batch.
 *
 * If a file conflicts, it will show up in the list.
 *
 * @param db         The opened database.
 * @param batch      The batch of packages to check.
 * @param errorList  A linked list of missing or conflicting dependencies.
 * @param errorCount The number of items in @a errorList.
 *
 * @return PM_SUCCESS on success. PM_DEP_ERROR on missing or conflicting
 *         dependency. Other errors if there are problems with the database
 *         or package.
 *
 * @see pmCheckDeps(3)
 */
PmStatus pmCheckBatchDeps(PmDatabase *db, PmBatch *batch,
						  PmDependency **errorList, unsigned int *errorCount);

#ifdef __cplusplus
}
#endif

#endif /* _LIBPACKMAN_DEPCHECK_H_ */
