/**
 * @file libpackman/listeners.h Progression notification listeners.
 * 
 * $Id: listeners.h,v 1.10 2002/03/18 09:51:14 chipx86 Exp $
 *
 * @Copyright (C) 1999-2002 The GNUpdate Project.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef _LIBPACKMAN_LISTENERS_H_
#define _LIBPACKMAN_LISTENERS_H_

#ifdef __cplusplus
extern "C" {
#endif

/**
 * A type of event.
 */
typedef enum
{
	PM_EVENT_PREPARE,      /**< Preparation for an operation.        */
	PM_EVENT_DEPGRAPH,     /**< Dependency graph is being generated. */
	PM_EVENT_DEPCHECK,     /**< Dependencies are being checked.      */
	PM_EVENT_INSTALL,      /**< Package install event.               */
	PM_EVENT_UNINSTALL,    /**< Package uninstall event.             */
	PM_EVENT_CREATE_DB,    /**< Database creation event.             */
	PM_EVENT_IMPORT_DB,    /**< Database import event.               */
	PM_EVENT_REBUILD_DB    /**< Database rebuild event.              */

} PmEventType;

/**
 * Registers an event listener callback function for the specified event type.
 *
 * @param type     The type of event to register the callback for.
 * @param callback The callback function to call.
 *
 * @see pmBroadcastEvent()
 * @see pmUnregisterEventListener()
 */
void pmRegisterEventListener(PmEventType type,
							 void (*callback)(PmEventType event_type,
											  int amount, int total,
											  void *data));

/**
 * Unregisters the specified event listener.
 *
 * @param type     The type of event.
 * @param callback The callback function to unregister.
 *
 * @see pmBroadcastEvent()
 * @see pmRegisterEventListener()
 */
void pmUnregisterEventListener(PmEventType type,
							   void (*callback)(PmEventType event_type,
												int amount, int total,
												void *data));

/**
 * Broadcasts an event of the specified type to all listeners.
 *
 * @param type   The type of event to broadcast.
 * @param amount The current amount of the way through (max of @a total).
 * @param total  The total number of steps.
 * @param data   Data associated with the event.
 *
 * @see pmRegisterEventListener()
 * @see pmUnregisterEventListener()
 */
void pmBroadcastEvent(PmEventType type, int amount, int total, void *data);

#ifdef __cplusplus
}
#endif

#endif /* _LIBPACKMAN_LISTENERS_H_ */
