/**
 * @file libpackman/package_api.h Package I/O API
 * 
 * $Id: package_api.h,v 1.24 2002/03/06 01:36:08 chipx86 Exp $
 *
 * @Copyright (C) 1999-2002 The GNUpdate Project.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef _LIBPACKMAN_PACKAGE_API_H_
#define _LIBPACKMAN_PACKAGE_API_H_

#include <packman.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Opens a package from a file.
 *
 * @param filename The file to read in.
 * @param mode     The access mode.
 * 
 * @return A PmPackage structure representing the package,
 *         or NULL if the package could not be opened.
 */
PmPackage *pmPackageRead(const char *filename, PmAccessMode mode);

/**
 * Extracts a single file from an archive.
 *
 * @param package     The PmPackage structure.
 * @param archivePath The path of the file in the archive.
 * @param fsPath      The destination path on the filesystem.
 *
 * @return The status of the operation.
 *
 * @see pmPackageExtractAll()
 */
PmStatus pmPackageExtractFile(PmPackage *package, const char *archivePath,
							  const char *fsPath);

/**
 * Extracts the entire archive.
 *
 * @param package The package containing the files to extract.
 *
 * @return The status of the operation.
 *
 * @see pmPackageExtractFile()
 */
PmStatus pmPackageExtractAll(PmPackage *package);

/**
 * Updates the progress of a package's installation or uninstallation.
 *
 * @param package The package.
 */
void pmPackageUpdateProgress(PmPackage *package);

#ifdef __cplusplus
};
#endif

#endif /* _LIBPACKMAN_PACKAGE_API_H_ */
