/**
 * @file libpackman/script.h Package script functions
 *
 * $Id: script.h,v 1.1 2002/04/25 03:34:13 chipx86 Exp $
 *
 * @Copyright (C) 1999-2002 The GNUpdate Project.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef _LIBPACKMAN_SCRIPT_H_
#define _LIBPACKMAN_SCRIPT_H_

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Types of scripts.
 */
typedef enum
{
	PM_SCRIPT_PRE,       /**< Pre-event script.  */
	PM_SCRIPT_POST,      /**< Post-event script. */
	PM_SCRIPT_TRIGGER    /**< Trigger script.    */

} PmScriptType;

/**
 * Script events.
 */
typedef enum
{
	PM_SCRIPTEVT_INSTALL,   /**< Installation.   */
	PM_SCRIPTEVT_UNINSTALL  /**< Uninstallation. */

} PmScriptEvent;

/**
 * Script errors.
 */
typedef enum
{
	PM_SCRIPTERR_SUCCESS,    /**< Successful execution of a script.  */
	PM_SCRIPTERR_NOT_FOUND,  /**< Specified script not found.        */
	PM_SCRIPTERR_INTERPERR   /**< Error with the script interpreter. */

} PmScriptError;

#include <libpackman/package.h>

/**
 * Executes the specified script(s) in a package.
 *
 * If this is a trigger script, @a trigger must be the name of a package.
 * If this is not a trigger script, @a should be @c NULL.
 * 
 * @param package The package containing the scripts.
 * @param type    The type of script.
 * @param event   The event.
 * @param trigger The name of a package for a trigger, or @c NULL if the
 *                specified script is not a trigger script.
 *
 * @return The error type.
 *
 * @see PmScriptError
 */
PmScriptError pmExecuteScript(PmPackage *package, PmScriptType type,
							  PmScriptEvent event, const char *trigger);

#ifdef __cplusplus
};
#endif

#endif /* _LIBPACKMAN_SCRIPT_H_ */
