/**
 * @file libpackman/transaction.h Transaction functions
 *
 * $Id: transaction.h,v 1.5 2002/06/07 08:21:48 chipx86 Exp $
 *
 * @Copyright (C) 1999-2002 The GNUpdate Project.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef _LIBPACKMAN_TRANSACTION_H_
#define _LIBPACKMAN_TRANSACTION_H_

#include <packman.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Types of transactions.
 */
typedef enum
{
	PM_TRANSACTION_INSTALL,     /**< Installing a package.               */
	PM_TRANSACTION_UNINSTALL,   /**< Uninstalling a package.             */
	PM_TRANSACTION_DB_ADD,      /**< Adding a package to a database.     */
	PM_TRANSACTION_DB_REMOVE    /**< Removing a package from a database. */

} PmTransactionType;

/**
 * A transaction.
 */
typedef struct
{
	PmTransactionType type;   /**< The type of transaction.           */

	PmDatabase *db;           /**< The database to work in.           */
	PmBatch *packages;        /**< The packages to work with.         */

	char checkDeps;           /**< If 1, perform dependency checking. */

} PmTransaction;

/**
 * Builds a transaction structure.
 *
 * @param db   The database to work with.
 * @param type The type of transaction.
 *
 * @return A PmTransaction structure.
 *
 * @see pmDestroyTransaction()
 */
PmTransaction *pmNewTransaction(PmDatabase *db, PmTransactionType type);

/**
 * Destroys a PmTransaction structure.
 *
 * @param transaction The transaction to destroy.
 *
 * @see pmNewTransaction()
 */
void pmDestroyTransaction(PmTransaction *transaction);

/**
 * Performs a transaction.
 *
 * @param transaction The transaction to perform.
 * @param error       The resulting errors, or NULL.
 *
 * @return The status of the transaction.
 */
PmStatus pmPerformTransaction(PmTransaction *transaction,
							  PmTransactionError **error);

#ifdef __cplusplus
};
#endif

#endif /* _LIBPACKMAN_TRANSACTION_H_ */

