/**
 * @file libpackman/transerror.h Transaction Error functions
 *
 * $Id: transerror.h,v 1.4 2002/06/07 08:21:48 chipx86 Exp $
 *
 * @Copyright (C) 1999-2002 The GNUpdate Project.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef _LIBPACKMAN_TRANSERROR_H_
#define _LIBPACKMAN_TRANSERROR_H_

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Types of transaction errors.
 */
typedef enum
{
	PM_TRANSERR_EXTRACT,       /**< Error extracting files from a package.  */
	PM_TRANSERR_DB_ADD,        /**< Error adding to the database.           */
	PM_TRANSERR_DB_REMOVE,     /**< Error removing from the database.       */
	PM_TRANSERR_MISSING_DEPS,  /**< Missing dependencies.                   */
	PM_TRANSERR_FILE_CONFLICT, /**< File conflicts.                         */
	PM_TRANSERR_DEP_CONFLICT   /**< Dependency conflicts.                   */

} PmTransErrorType;

/**
 * A transaction error.
 *
 * This structure contains information on what went wrong. This is only
 * returned if there was an error at all.
 */
typedef struct
{
	PmTransErrorType type;          /**< The type of transaction error. */
	PmPackage *failedPackage;       /**< The failed package.            */

	PmDependency *failedDeps;       /**< Failed dependencies.           */
	unsigned int  failedDepCount;   /**< Number of failed dependencies. */

} PmTransactionError;

/**
 * Creates a new PmTransactionError structure.
 *
 * @param type The type of transaction error.
 *
 * @return A new PmTransactionError structure.
 *
 * @see pmDestroyTransError()
 */
PmTransactionError *pmNewTransError(PmTransErrorType type);

/**
 * Destroys a PmTransactionError structure.
 *
 * @param transError The transaction error to destroy.
 *
 * @see pmNewTransError()
 */
void pmDestroyTransError(PmTransactionError *transError);

#ifdef __cplusplus
};
#endif

#endif /* _LIBPACKMAN_TRANSERROR_H_ */
