# Configure paths for libpackman
# Christian Hammond   5 August 2000

dnl AM_PATH_PACKMAN([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for PACKMAN, and define PACKMAN_CFLAGS and PACKMAN_LIBS
dnl
AC_DEFUN(AM_PATH_PACKMAN,
[dnl 
dnl Get the cflags and libraries from the packman-config script
dnl
AC_ARG_WITH(packman-prefix,[  --with-packman-prefix=PFX   Prefix where packman is installed (optional)],
            packman_config_prefix="$withval", packman_config_prefix="")
AC_ARG_WITH(packman-exec-prefix,[  --with-packman-exec-prefix=PFX Exec prefix where packman is installed (optional)],
            packman_config_exec_prefix="$withval", packman_config_exec_prefix="")
AC_ARG_ENABLE(packmantest, [  --disable-packmantest       Do not try to compile and run a test packman program],
            , enable_packmantest=yes)


  if test x$packman_config_exec_prefix != x ; then
     packman_config_args="$packman_config_args --exec-prefix=$packman_config_exec_prefix"
     if test x${PACKMAN_CONFIG+set} != xset ; then
        PACKMAN_CONFIG=$packman_config_exec_prefix/bin/packman-config
     fi
  fi
  if test x$packman_config_prefix != x ; then
     packman_config_args="$packman_config_args --prefix=$packman_config_prefix"
     if test x${PACKMAN_CONFIG+set} != xset ; then
        PACKMAN_CONFIG=$packman_config_prefix/bin/packman-config
     fi
  fi

  AC_PATH_PROG(PACKMAN_CONFIG, packman-config, no)
	
  min_packman_version=ifelse([$1], ,0.3.2,$1)
  AC_MSG_CHECKING([for libpackman - version >= $min_packman_version])
  no_packman=""
  if test "$PACKMAN_CONFIG" = "no" ; then
    no_packman=yes
  else
    PACKMAN_CFLAGS=`$PACKMAN_CONFIG $packman_config_args --cflags`
    PACKMAN_LIBS=`$PACKMAN_CONFIG $packman_config_args --libs`
    packman_config_major_version=`$PACKMAN_CONFIG $packman_config_args --version | \
           sed 's/[[^0-9]]*\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    packman_config_minor_version=`$PACKMAN_CONFIG $packman_config_args --version | \
           sed 's/[[^0-9]]*\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    packman_config_micro_version=`$PACKMAN_CONFIG $packman_config_args --version | \
           sed 's/[[^0-9]]*\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`

    if test "x$enable_packmantest" = "xyes" ; then
      ac_save_CFLAGS="$CFLAGS"
      ac_save_LIBS="$LIBS"
      CFLAGS="$CFLAGS $PACKMAN_CFLAGS"
      LIBS="$PACKMAN_LIBS $LIBS"
dnl
dnl Now check if the installed packman is sufficiently new. (Also sanity
dnl checks the results of packman-config to some extent
dnl
      rm -f conf.packmantest
      AC_TRY_RUN([
#include <packman.h>
#include <stdio.h>
#include <stdlib.h>

char *my_strdup(char *str)
{
	char *new_str;

	if (str)
	{
		new_str = (char *)malloc((strlen(str) + 1) * sizeof(char));
		strcpy(new_str, str);
	}
	else
		new_str = NULL;
	
	return new_str;
}

int 
main ()
{
  int major, minor, micro;
  char *tmp_version;

  system ("touch conf.packmantest");

  /* HP/UX 9 (%@#!) writes to sscanf strings */
  tmp_version = my_strdup("$min_packman_version");
  if (sscanf(tmp_version, "%d.%d.%d", &major, &minor, &micro) != 3) {
     printf("%s, bad version string\n", "$min_packman_version");
     exit(1);
   }

  if (($packman_config_major_version  > major) ||
     (($packman_config_major_version == major) && ($packman_config_minor_version > minor)) ||
     (($packman_config_major_version == major) && ($packman_config_minor_version == minor) &&
      ($packman_config_micro_version >= micro)))
    {
			return 0;
		}
		else
		{
      printf("\n*** 'packman-config --version' returned %d.%d.%d, but packman (%d.%d.%d)\n", 
             $packman_config_major_version, $packman_config_minor_version, $packman_config_micro_version,
             major, minor, micro);
      printf ("*** was found! If packman-config was correct, then it is best\n");
      printf ("*** to remove the old version of packman. You may also be able to fix the error\n");
      printf("*** by modifying your LD_LIBRARY_PATH enviroment variable, or by editing\n");
      printf("*** /etc/ld.so.conf. Make sure you have run ldconfig if that is\n");
      printf("*** required on your system.\n");
      printf("*** If packman-config was wrong, set the environment variable PACKMAN_CONFIG\n");
      printf("*** to point to the correct copy of packman-config, and remove the file config.cache\n");
      printf("*** before re-running configure\n");
			return 1;
    } 
}
],, no_packman=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
     fi
  fi
  if test "x$no_packman" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$2], , :, [$2])     
  else
     AC_MSG_RESULT(no)
     if test "$PACKMAN_CONFIG" = "no" ; then
       echo "*** The packman-config script installed by packman could not be found"
       echo "*** If packman was installed in PREFIX, make sure PREFIX/bin is in"
       echo "*** your path, or set the PACKMAN_CONFIG environment variable to the"
       echo "*** full path to packman-config."
     else
       if test -f conf.packmantest ; then
        :
       else
          echo "*** Could not run packman test program, checking why..."
          CFLAGS="$CFLAGS $PACKMAN_CFLAGS"
          LIBS="$LIBS $PACKMAN_LIBS"
          AC_TRY_LINK([
#include <packman.h>
#include <stdio.h>
],      [ return (($packman_config_major_version) || ($packman_config_minor_version) || ($packman_config_micro_version)); ],
        [ echo "*** The test program compiled, but did not run. This usually means"
          echo "*** that the run-time linker is not finding packman or finding the wrong"
          echo "*** version of packman. If it is not finding packman, you'll need to set your"
          echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
          echo "*** to the installed location  Also, make sure you have run ldconfig if that"
          echo "*** is required on your system"
          echo "***"
          echo "*** If you have an old version installed, it is best to remove it, although"
          echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH"
          echo "***"
          echo "*** If you have a RedHat 5.0 system, you should remove the packman package that"
          echo "*** came with the system with the command"
          echo "***"
          echo "***    rpm --erase --nodeps packman packman-devel" ],
        [ echo "*** The test program failed to compile or link. See the file config.log for"
          echo "*** the exact error that occured. This usually means packman was incorrectly"
          echo "*** installed or that you have moved packman since it was installed. In the"
          echo "*** later case, you may want to edit the packman-config"
	  echo "*** script: $PACKMAN_CONFIG" ])
	  
          CFLAGS="$ac_save_CFLAGS"
          LIBS="$ac_save_LIBS"
       fi
     fi
     PACKMAN_CFLAGS=""
     PACKMAN_LIBS=""
     ifelse([$3], , :, [$3])
  fi
  AC_SUBST(PACKMAN_CFLAGS)
  AC_SUBST(PACKMAN_LIBS)
  rm -f conf.packmantest
])
